jamtorch.prototype package
==========================

Submodules
----------

jamtorch.prototype.optim module
-------------------------------

.. automodule:: jamtorch.prototype.optim
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.prototype.pytorch\_util module
---------------------------------------

.. automodule:: jamtorch.prototype.pytorch_util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jamtorch.prototype
   :members:
   :undoc-members:
   :show-inheritance:
